@@ -32,7 +32,7 @@ def md5it(f, MAXSIZE, VERBOSITY=0, PROFILES=False):
 
 TMPDB1FNAME="dupfilefind1_tmp.db"
 TMPDB2FNAME="dupfilefind2_tmp.db"
-def dffem(VERBOSITY, IGNOREDIRS, HARDLINKEM, DELETEEM, MINSIZE, MAXSIZE, PROFILES, NOFOLLOWSYMLINKS, DIRS, WINDOWS):
+def dffem(VERBOSITY, IGNOREDIRS, HARDLINKEM, DELETEEM, MINSIZE, MAXSIZE, PROFILES, INCLUDE_NAMES_IN_PROFILES, NOFOLLOWSYMLINKS, DIRS, WINDOWS):
     # on Windows and Cygwin:
     # d1 = { size: [fname]} }
     # d2 = { fname: "1" or "0" } # also for dirs, with "0" for value
@@ -50,12 +50,12 @@ def dffem(VERBOSITY, IGNOREDIRS, HARDLINKEM, DELETEEM, MINSIZE, MAXSIZE, PROFILE
     fileutil.remove_if_possible(db2fname)
     tempd.register_file(d2)
     try:
-        return _dffem(VERBOSITY, IGNOREDIRS, HARDLINKEM, DELETEEM, MINSIZE, MAXSIZE, PROFILES, NOFOLLOWSYMLINKS, DIRS, WINDOWS, d1, d2)
+        return _dffem(VERBOSITY, IGNOREDIRS, HARDLINKEM, DELETEEM, MINSIZE, MAXSIZE, PROFILES, INCLUDE_NAMES_IN_PROFILES, NOFOLLOWSYMLINKS, DIRS, WINDOWS, d1, d2)
     finally:
         tempd.shutdown()
 
 DUMPSEMPTYLIST = dumps([])
-def _dffem(VERBOSITY, IGNOREDIRS, HARDLINKEM, DELETEEM, MINSIZE, MAXSIZE, PROFILES, NOFOLLOWSYMLINKS, DIRS, WINDOWS, d1, d2, next_power_of_k=mathutil.next_power_of_k):
+def _dffem(VERBOSITY, IGNOREDIRS, HARDLINKEM, DELETEEM, MINSIZE, MAXSIZE, PROFILES, INCLUDE_NAMES_IN_PROFILES, NOFOLLOWSYMLINKS, DIRS, WINDOWS, d1, d2, next_power_of_k=mathutil.next_power_of_k):
     assert not (HARDLINKEM and DELETEEM) # at most one of these
 
     # First pass: build map from size, dev, inode number to filenames.
@@ -176,7 +176,10 @@ def _dffem(VERBOSITY, IGNOREDIRS, HARDLINKEM, DELETEEM, MINSIZE, MAXSIZE, PROFIL
                     break
 
                 if PROFILES:
-                    print "%s:%s" % (md5h, size)
+                    if INCLUDE_NAMES_IN_PROFILES:
+                        print "%s:%s:%s" % (fname, md5h, size)
+                    else:
+                        print "%s:%s" % (md5h, size)
 
                 d4 = d3.setdefault(md5h, {})
                 if WINDOWS:
